import type { Ability } from "@proscenium/playbill";
import { HTML } from "./base/html";

interface AbilityCardProps {
  ability: Ability;
}

export function AbilityCard({ ability }: AbilityCardProps) {
  const costs: React.ReactNode[] = [];

  if (ability.ap > 0) {
    costs.push(
      <span key="ap" className="ability-cost ap">
        {ability.ap} AP
      </span>,
    );
  }

  if (ability.hp > 0) {
    costs.push(
      <span key="hp" className="ability-cost hp">
        {ability.hp} HP
      </span>,
    );
  }

  if (ability.ep > 0) {
    costs.push(
      <span key="ep" className="ability-cost ep">
        {ability.ep} EP
      </span>,
    );
  }

  const damage =
    ability.damage !== null ? (
      <div className={`ability-damage ${ability.damage.type}`}>
        {ability.damage.amount} {ability.damage.type === "phy" ? "Phy" : "Arc"}
      </div>
    ) : null;

  const roll =
    ability.roll !== "none" ? (
      <div className={`ability-roll ${ability.roll}`}>{ability.roll}</div>
    ) : null;

  const type = (
    <span className={`ability-type ${ability.type}`}>{ability.type}</span>
  );

  const classList = `ability ability-${ability.type}`;

  return (
    <div className={classList} data-component-id={ability.id}>
      <div className="ability-header">
        <h4>{ability.name}</h4>
        <div className="ability-details">
          {type}
          {roll}
          {damage}
          {costs}
        </div>
      </div>
      <HTML className="ability-content" html={ability.description} />
    </div>
  );
}
