import classNames from "classnames";
import type React from "react";

interface SectionProps {
  type: string;
  title: string;
  children: React.ReactNode;
  preInfo?: React.ReactNode;
  info?: React.ReactNode;
  componentId?: string;
  leftCornerTag?: React.ReactNode;
  rightCornerTag?: React.ReactNode;
}

export function Section({
  type,
  title,
  children,
  preInfo,
  info,
  componentId,
  leftCornerTag,
  rightCornerTag,
}: SectionProps) {
  const sectionClasses = classNames("section", type);
  const headerClasses = classNames("section-header", `${type}-header`);
  const contentClasses = classNames("section-content", `${type}-content`);

  return (
    <section className={sectionClasses} data-component-id={componentId}>
      <div className={headerClasses}>
        {preInfo}
        <h2>{title}</h2>
        {info}
      </div>
      <div className="section-tag section-tag--left">{leftCornerTag}</div>
      <div className="section-tag section-tag--right">{rightCornerTag}</div>
      <div className={contentClasses}>{children}</div>
    </section>
  );
}
