import type {
  ImageResource,
  Resource,
  TableResource,
  TextResource,
} from "@proscenium/playbill";
import { Section } from "./base/section";
import { HTML } from "./base/html";

interface TextResourceSectionProps {
  resource: TextResource;
}

function TextResourceSection({ resource }: TextResourceSectionProps) {
  return (
    <Section
      type="resource"
      componentId={resource.id}
      title={resource.name}
      info={
        <ul className="resource-categories">
          {resource.categories.map((category) => (
            <li key={category}>{category}</li>
          ))}
        </ul>
      }
    >
      <HTML html={resource.description} />
    </Section>
  );
}

interface ImageResourceSectionProps {
  resource: ImageResource;
}

function ImageResourceSection({ resource }: ImageResourceSectionProps) {
  return (
    <Section
      type="resource"
      componentId={resource.id}
      title={resource.name}
      info={
        <ul className="resource-categories">
          {resource.categories.map((category) => (
            <li key={category}>{category}</li>
          ))}
        </ul>
      }
    >
      <figure className="resource-image">
        <img src={resource.url} alt={resource.name} />
        <figcaption
          dangerouslySetInnerHTML={{ __html: resource.description }}
        />
      </figure>
    </Section>
  );
}

interface TableResourceSectionProps {
  resource: TableResource;
}

function TableResourceSection({ resource }: TableResourceSectionProps) {
  const [headers, ...rows] = resource.data;
  return (
    <Section
      type="resource"
      componentId={resource.id}
      title={resource.name}
      info={
        <ul className="resource-categories">
          {resource.categories.map((category) => (
            <li key={category}>{category}</li>
          ))}
        </ul>
      }
    >
      <table className="resource-table">
        <thead>
          <tr>
            {headers.map((header) => (
              <th key={header} dangerouslySetInnerHTML={{ __html: header }} />
            ))}
          </tr>
        </thead>
        <tbody>
          {rows.map((row, i) => (
            <tr key={i}>
              {row.map((cell, j) => (
                <td key={j} dangerouslySetInnerHTML={{ __html: cell }} />
              ))}
            </tr>
          ))}
        </tbody>
      </table>
    </Section>
  );
}

interface ResourceSectionProps {
  resource: Resource;
}

export function ResourceSection({ resource }: ResourceSectionProps) {
  switch (resource.type) {
    case "text":
      return <TextResourceSection resource={resource} />;
    case "image":
      return <ImageResourceSection resource={resource} />;
    case "table":
      return <TableResourceSection resource={resource} />;
  }
}
